@@ -583,20 +583,28 @@ class ResponseObject(object):
 	# support '==' & '!=' operator.
 	def __eq__(self, dictionary):
 		if isinstance(dictionary, dict):
-			return str(self.sort()) == str(Files.Dictionary(dictionary).sort())
-		elif not isinstance(dictionary, (self.__class__, Dictionary)):
-			return False
-		return str(self.sort()) == str(dictionary.sort())
+			return str(self.sort()) == str(Dictionary(dictionary).sort())
+		elif isinstance(dictionary, Dictionary):
+			return str(self.sort()) == str(dictionary.sort())
+		else:
+			try:
+				return str(self.sort()) == str(dictionary.sort())
+			except:
+				return False
 	def __ne__(self, dictionary):
 		if isinstance(dictionary, dict):
-			return str(self.sort()) !=  str(Files.Dictionary(dictionary).sort())
-		elif not isinstance(dictionary, (self.__class__, Dictionary)):
-			return True
-		return str(self.sort()) != str(dictionary.sort())
+			return str(self.sort()) != str(Dictionary(dictionary).sort())
+		elif isinstance(dictionary, Dictionary):
+			return str(self.sort()) != str(dictionary.sort())
+		else:
+			try:
+				return str(self.sort()) != str(dictionary.sort())
+			except:
+				return False
 	# support 'in' operator.
 	def __contains__(self, response):
 		keys = self.keys()
-		if isinstance(response, (list, Formats.Array)):
+		if isinstance(response, (list, Array)):
 			for i in response:
 				if response in keys:
 					return True
